WMR300 - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# WMR300

A single WMR300 console supports 1 wind, 1 rain, 1 UV, and up to 8 temperature/humidity sensors.

The WMR300 sensors send at different rates:

WMR300 transmission periods
sensor | period
--- | ---
Wind | 2.5 to 3 seconds
T/H | 10 to 12 seconds
Rain | 20 to 24 seconds

The console contains the pressure sensor. The console reports pressure every 15 minutes.

The station emits partial packets, which may confuse some online services.

The rain counter has a limit of 400 inches (10160 mm). The counter does not wrap around; it must be reset when it hits the limit, otherwise additional rain data will not be recorded.

The logger stores about 50,000 records. When the logger fills up, it stops recording data.

When WeeWX starts up it will attempt to download all records from the console since the last record in the archive database. This can take as much as couple of hours, depending on the number of records in the logger and the speed of the computer and disk.

## Configuring with `wee_device`

The WMR300 stations cannot be configured with the utility `wee_device`.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

WMR300 station data
Database Field | Observation | Loop | Archive
barometer | barometer | H | H
pressure | pressure | H | S
altimeter |  | S | S
inTemp | temperature_0 | H | H
inHumidity | humidity_0 | H | H
windSpeed | wind_avg | H | H
windDir | wind_dir | H | H
windGust | wind_gust | H | H
windGustDir | wind_gust_dir | H | H
rain | rain | D | D
| rain_total | H | H
rainRate | rain_rate | H | H
outTemp | temperature_1 | H | H
outHumidity | humidity_1 | H | H
dewpoint | dewpoint_1 | H | H
heatindex | heatindex_1 | H | H
windchill | windchill | H | H
extraTemp1 | temperature_2 | H | H
extraHumid1 | humidity_2 | H | H
extraDewpoint1 | dewpoint_2 | H | H
extraHeatindex1 | heatindex_2 | H | H
extraTemp2 | temperature_3 | H | H
extraHumid2 | humidity_3 | H | H
extraDewpoint2 | dewpoint_3 | H | H
extraHeatindex2 | heatindex_3 | H | H
extraTemp3 | temperature_4 | H | H
extraHumid3 | humidity_4 | H | H
extraDewpoint3 | dewpoint_4 | H | H
extraHeatindex3 | heatindex_4 | H | H
extraTemp4 | temperature_5 | H | H
extraHumid4 | humidity_5 | H | H
extraDewpoint4 | dewpoint_5 | H | H
extraHeatindex4 | heatindex_5 | H | H
extraTemp5 | temperature_6 | H | H
extraHumid5 | humidity_6 | H | H
extraDewpoint5 | dewpoint_6 | H | H
extraHeatindex5 | heatindex_6 | H | H
extraTemp6 | temperature_7 | H | H
extraHumid6 | humidity_7 | H | H
extraDewpoint6 | dewpoint_7 | H | H
extraHeatindex6 | heatindex_7 | H | H
extraTemp7 | temperature_8 | H | H
extraHumid7 | humidity_8 | H | H
extraDewpoint7 | dewpoint_8 | H | H
extraHeatindex7 | heatindex_8 | H | H

Each packet contains a subset of all possible readings.

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service